@@ -2,7 +2,7 @@ import json
 from pathlib import Path
 
 from starlette.responses import Response
-from pymultirole_plugins.schema import Document
+from pymultirole_plugins.v1.schema import Document
 
 from pyformatters_tabular.tabular import TabularFormatter, TabularParameters, OutputFormat
 
